==> percona-server-mongodb_4.4.4.orig.tar.gz: percona-server-mongodb-4.4.4-6/src/mongo/db/storage/kv/kv_engine_test_harness.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <functional>
#include <memory>

#include "mongo/db/storage/kv/kv_engine.h"

namespace mongo {

class ClockSource;

/**
 * Creates a harness for generic KVEngine testing of all KVEngine implementations.
 *
 * A particular KVHarnessHelper implementation (with a particular KVEngine implementation) will
 * implement registerFactory() and create() such that generic unit tests can create() and test the
 * particular KVHarnessHelper implementation. This library can be pulled into a particular
 * implementation's CppUnitTest to exercise the generic test coverage on that implementation.
 */
class KVHarnessHelper {
public:
    virtual ~KVHarnessHelper() {}

    // returns same thing for entire life
    virtual KVEngine* getEngine() = 0;

    virtual KVEngine* restartEngine() = 0;

    static std::unique_ptr<KVHarnessHelper> create();
    static void registerFactory(std::function<std::unique_ptr<KVHarnessHelper>()> factory);
};

}  // namespace mongo

==> percona-server-mongodb-36_3.6.12.orig.tar.gz: percona-server-mongodb-3.6.12-3.2/src/mongo/db/storage/kv/kv_engine_test_harness.h <==
// kv_engine_test_harness.h


/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <memory>

#include "mongo/db/storage/kv/kv_engine.h"
#include "mongo/stdx/functional.h"

namespace mongo {

class ClockSource;

class KVHarnessHelper {
public:
    virtual ~KVHarnessHelper() {}

    // returns same thing for entire life
    virtual KVEngine* getEngine() = 0;

    virtual KVEngine* restartEngine() = 0;

    static std::unique_ptr<KVHarnessHelper> create();
    static void registerFactory(stdx::function<std::unique_ptr<KVHarnessHelper>()> factory);
};

}  // namespace mongo
